==> liblxqt_0.16.0.orig.tar.xz: liblxqt-0.16.0/translations/liblxqt_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>LXQt Power Manager Error</source>
        <translation>Error del gestor d&apos;energia de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>Hibernate failed.</source>
        <translation>Ha falla la hibernació.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="163"/>
        <source>Notifications Fallback</source>
        <translation>Replegament de les notificacions</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="108"/>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="115"/>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="122"/>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="129"/>
        <source>Shutdown</source>
        <translation>Apaga</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="136"/>
        <source>Logout</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="148"/>
        <source>LXQt Session Suspend</source>
        <translation>Suspensió de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="149"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Esteu segur que voleu posar en suspensió el vostre ordinador?&lt;p&gt;Suspèn l&apos;ordinador a un estat de baix consum. L&apos;estat del sistema no es preserva si es perd l&apos;alimentació.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernació de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Esteu segur que voleu posar en hibernació el vostre ordinador?&lt;p&gt;Hiberna l&apos;ordinador a un estat de baix consum. L&apos;estat del sistema no es preserva si es perd l&apos;alimentació.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Reboot</source>
        <translation>Reinici de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Esteu segur que voleu reiniciar el vostre ordinador? Es perdran tots els treballs que no s&apos;hagin desat...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Shutdown</source>
        <translation>Aturada de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Esteu segur que voleu apagar el vostre ordinador? Es perdran tots els treballs que no s&apos;hagin desat...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Logout</source>
        <translation>Tancament de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Esteu segur que voleu tancar la sessió? Es perdrà tot aquell treball que no s&apos;hagi desat...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>LXQt Power Manager Error</source>
        <translation>Error del gestor d&apos;energia de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Ha fallat la hibernació.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Ha fallat la suspensió.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="160"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="164"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="242"/>
        <source>Lock Screen</source>
        <translation>Bloqueja la pantalla</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="155"/>
        <source>Screen Saver Error</source>
        <translation>Error de l&apos;estalvi de pantalla</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Trieu la pàgina a mostrar.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Error del gestor d&apos;energia</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface no és vàlid</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Error del gestor d&apos;energia (crida de D-BUS)</translation>
    </message>
</context>
</TS>

==> liblxqt_1.1.0.orig.tar.xz: liblxqt-1.1.0/translations/liblxqt_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>LXQt Power Manager Error</source>
        <translation>Error del gestor d&apos;energia de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>Hibernate failed.</source>
        <translation>Ha falla la hibernació.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="163"/>
        <source>Notifications Fallback</source>
        <translation>Replegament de les notificacions</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="108"/>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="115"/>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="122"/>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="129"/>
        <source>Shutdown</source>
        <translation>Apaga</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="136"/>
        <source>Logout</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="148"/>
        <source>LXQt Session Suspend</source>
        <translation>Suspensió de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="149"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Esteu segur que voleu posar en suspensió el vostre ordinador?&lt;p&gt;Suspèn l&apos;ordinador a un estat de baix consum. L&apos;estat del sistema no es preserva si es perd l&apos;alimentació.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernació de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Esteu segur que voleu posar en hibernació el vostre ordinador?&lt;p&gt;Hiberna l&apos;ordinador a un estat de baix consum. L&apos;estat del sistema no es preserva si es perd l&apos;alimentació.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Reboot</source>
        <translation>Reinici de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Esteu segur que voleu reiniciar el vostre ordinador? Es perdran tots els treballs que no s&apos;hagin desat...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Shutdown</source>
        <translation>Aturada de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Esteu segur que voleu apagar el vostre ordinador? Es perdran tots els treballs que no s&apos;hagin desat...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Logout</source>
        <translation>Tancament de la sessió LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Esteu segur que voleu tancar la sessió? Es perdrà tot aquell treball que no s&apos;hagi desat...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>LXQt Power Manager Error</source>
        <translation>Error del gestor d&apos;energia de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Ha fallat la hibernació.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Ha fallat la suspensió.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="160"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>No s&apos;ha pogut executar «%1». Assegureu-vos que teniu un bloquejador/estalvi de pantalla compatible amb xdg-screensaver instal·lat i actiu.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="164"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>No s&apos;ha pogut executar «%1». Assegureu-vos que el bloquejador/estalvi de pantalla especificat està instal·lat i actiu.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="242"/>
        <source>Lock Screen</source>
        <translation>Bloqueja la pantalla</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="155"/>
        <source>Screen Saver Error</source>
        <translation>Error de l&apos;estalvi de pantalla</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Trieu la pàgina a mostrar.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Error del gestor d&apos;energia</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface no és vàlid</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Error del gestor d&apos;energia (crida de D-BUS)</translation>
    </message>
</context>
</TS>
